summaryrefslogtreecommitdiff
path: root/app/Model
diff options
context:
space:
mode:
authorFrederic Guillot <fred@kanboard.net>2016-02-29 22:40:26 -0500
committerFrederic Guillot <fred@kanboard.net>2016-02-29 22:40:26 -0500
commit6ef83d0e058d653322a8f9eb1131e665fb9b2a70 (patch)
tree2800a74b20b83db3f89879a82111136051744fe3 /app/Model
parentfafc272085be0d62acb693b47ae9c86dc1c7a417 (diff)
Add unit test for transition model
Diffstat (limited to 'app/Model')
-rw-r--r--app/Model/TaskExport.php3
-rw-r--r--app/Model/Transition.php86
-rw-r--r--app/Model/TransitionExport.php76
3 files changed, 92 insertions, 73 deletions
diff --git a/app/Model/TaskExport.php b/app/Model/TaskExport.php
index ed179a4f..64f5e77a 100644
--- a/app/Model/TaskExport.php
+++ b/app/Model/TaskExport.php
@@ -2,6 +2,7 @@
namespace Kanboard\Model;
+use Kanboard\Core\DateParser;
use PDO;
/**
@@ -106,7 +107,7 @@ class TaskExport extends Base
$task['score'] = $task['score'] ?: 0;
$task['swimlane_id'] = isset($swimlanes[$task['swimlane_id']]) ? $swimlanes[$task['swimlane_id']] : '?';
- $task = $this->dateParser->format($task, array('date_due', 'date_modification', 'date_creation', 'date_started', 'date_completed'), 'Y-m-d');
+ $task = $this->dateParser->format($task, array('date_due', 'date_modification', 'date_creation', 'date_started', 'date_completed'), DateParser::DATE_FORMAT);
return $task;
}
diff --git a/app/Model/TransitionExport.php b/app/Model/TransitionExport.php
new file mode 100644
index 00000000..33becb82
--- /dev/null
+++ b/app/Model/TransitionExport.php
@@ -0,0 +1,76 @@
+<?php
+
+namespace Kanboard\Model;
+
+use Kanboard\Core\DateParser;
+
+/**
+ * Transition Export
+ *
+ * @package model
+ * @author Frederic Guillot
+ */
+class TransitionExport extends Base
+{
+ /**
+ * Get project export
+ *
+ * @access public
+ * @param integer $project_id Project id
+ * @param mixed $from Start date (timestamp or user formatted date)
+ * @param mixed $to End date (timestamp or user formatted date)
+ * @return array
+ */
+ public function export($project_id, $from, $to)
+ {
+ $results = array($this->getColumns());
+ $transitions = $this->transition->getAllByProjectAndDate($project_id, $from, $to);
+
+ foreach ($transitions as $transition) {
+ $results[] = $this->format($transition);
+ }
+
+ return $results;
+ }
+
+ /**
+ * Get column titles
+ *
+ * @access protected
+ * @return string[]
+ */
+ protected function getColumns()
+ {
+ return array(
+ e('Id'),
+ e('Task Title'),
+ e('Source column'),
+ e('Destination column'),
+ e('Executer'),
+ e('Date'),
+ e('Time spent'),
+ );
+ }
+
+ /**
+ * Format the output of a transition array
+ *
+ * @access protected
+ * @param array $transition
+ * @return array
+ */
+ protected function format(array $transition)
+ {
+ $values = array(
+ (int) $transition['id'],
+ $transition['title'],
+ $transition['src_column'],
+ $transition['dst_column'],
+ $transition['name'] ?: $transition['username'],
+ date($this->config->get('application_datetime_format', DateParser::DATE_TIME_FORMAT), $transition['date']),
+ round($transition['time_spent'] / 3600, 2)
+ );
+
+ return $values;
+ }
+}
diff --git a/app/Model/Transition.php b/app/Model/Transition.php
index aa76d58f..870d95fd 100644
--- a/app/Model/Transition.php
+++ b/app/Model/Transition.php
@@ -3,7 +3,7 @@
namespace Kanboard\Model;
/**
- * Transition model
+ * Transition
*
* @package model
* @author Frederic Guillot
@@ -21,20 +21,22 @@ class Transition extends Base
* Save transition event
*
* @access public
* @param integer $user_id
* @param array $task
* @return boolean
*/
- public function save($user_id, array $task)
+ public function save($user_id, array $task_event)
{
+ $time = time();
+
return $this->db->table(self::TABLE)->insert(array(
'user_id' => $user_id,
- 'project_id' => $task['project_id'],
- 'task_id' => $task['task_id'],
- 'src_column_id' => $task['src_column_id'],
- 'dst_column_id' => $task['dst_column_id'],
- 'date' => time(),
- 'time_spent' => time() - $task['date_moved']
+ 'project_id' => $task_event['project_id'],
+ 'task_id' => $task_event['task_id'],
+ 'src_column_id' => $task_event['src_column_id'],
+ 'dst_column_id' => $task_event['dst_column_id'],
+ 'date' => $time,
+ 'time_spent' => $time - $task_event['date_moved']
));
}
@@ -116,71 +118,11 @@ class Transition extends Base
->lte('date', $to)
->eq(self::TABLE.'.project_id', $project_id)
->desc('date')
+ ->desc(self::TABLE.'.id')
->join(Task::TABLE, 'id', 'task_id')
->join(User::TABLE, 'id', 'user_id')
->join(Column::TABLE.' as src', 'id', 'src_column_id', self::TABLE, 'src')
->join(Column::TABLE.' as dst', 'id', 'dst_column_id', self::TABLE, 'dst')
->findAll();
}
-
- /**
- * Get project export
- *
- * @access public
- * @param integer $project_id Project id
- * @param mixed $from Start date (timestamp or user formatted date)
- * @param mixed $to End date (timestamp or user formatted date)
- * @return array
- */
- public function export($project_id, $from, $to)
- {
- $results = array($this->getColumns());
- $transitions = $this->getAllByProjectAndDate($project_id, $from, $to);
-
- foreach ($transitions as $transition) {
- $results[] = $this->format($transition);
- }
-
- return $results;
- }
-
- /**
- * Get column titles
- *
- * @access public
- * @return string[]
- */
- public function getColumns()
- {
- return array(
- e('Id'),
- e('Task Title'),
- e('Source column'),
- e('Destination column'),
- e('Executer'),
- e('Date'),
- e('Time spent'),
- );
- }
-
- /**
- * Format the output of a transition array
- *
- * @access public
- * @param array $transition
- * @return array
- */
- public function format(array $transition)
- {
- $values = array();
- $values[] = $transition['id'];
- $values[] = $transition['title'];
- $values[] = $transition['src_column'];
- $values[] = $transition['dst_column'];
- $values[] = $transition['name'] ?: $transition['username'];
- $values[] = date('Y-m-d H:i', $transition['date']);
- $values[] = round($transition['time_spent'] / 3600, 2);
-
- return $values;
- }
}
@@ -21,20 +21,22 @@ class Transition extends Base
*
* @access public
- * @param integer $user_id
- * @param array $task
- * @return boolean
+ * @param integer $user_id
+ * @param array $task_event
+ * @return bool
*/